void waitingCommands() {
  if((millis() > command_time) && (command != 0)) {

    switch(command) {
      case 100:
        LoRa.beginPacket();
        LoRa.print("OK");
        LoRa.endPacket();
        break;

      case 1:
        sendPong();
        break;

      case 2:
        sendTime();
        break;

      case 3:
        for(int i = 0; i < 6; i++) {
          delay(1000);
          one_by_one = one_by_one_from + i;
          sendDelay();
        }
        break;

      case 4:
        sendLoRaSetting();
        break;

      case 5:
        sendLoRaSetting();
        delay(500);
        EEPROM.write(2, LoRa_SF);
        LoRa.setSpreadingFactor(LoRa_SF);
        break;

      case 6:
        for(byte i = 0; i < 6; i ++) {
          delay(1000);
          one_by_one = one_by_one_from + i;
          sendAlias();
        }
        break;

      case 7:
        sendTemp();
        break;

      case 8:
        sendBatLvl();
        break;
      
      case 9:
        sendUnitInfo();
        break;
    }

    command = 0;
  }
}
